import xlwt
import xlrd

def excelRead(filename,flip=False):
    wb = xlrd.open_workbook(filename)
    sheets = wb.sheets()
    sheetnames = [i.name for i in sheets]
    data=[] # 3d data set... sheets, rows, columns...
    for sheet in sheets:
        #print sheet.name
        data.append([]) #make a data store
        if flip:
            for i in range(sheet.ncols):
                data[-1].append(sheet.col_values(i))
        else:
            for i in range(sheet.nrows):
                data[-1].append(sheet.row_values(i))
    return data,sheetnames
def excelWrite(data,sheetnames,filename,flip=False):
    wb=xlwt.Workbook()
    for i,name in enumerate(sheetnames):
        ws=wb.add_sheet(name)
        for j in range(len(data[i])):
            for k in range(len(data[i][j])):
                if flip:
                    ws.write(k,j,data[i][j][k])
                else:
                    ws.write(j,k,data[i][j][k])
    wb.save(filename)

if __name__=='__main__':
    import numpy as np
    a=np.array([[1,2,3,4],
                [5,6,7,8],
                [9,10,11,12]])
    excelWrite([a],['NumericalListsTo12'],'/home/mashbudn/Desktop/testxlwt.xls')
    print excelRead('/home/mashbudn/Desktop/testxlwt.xls')



#! python
# -*- coding: utf-8 -*-

import os
import sys
import shutil
#from wx_py import __file__

import imp

name = 'SeedWaterSegmenter'

modulePath = imp.find_module(name)[1]

if sys.platform == "win32":
    try:
        # When running a binary installer, special functions like
        # get_special_folder_path, create_shortcut, and file_created
        # are "magically" available; see
        # http://docs.python.org/2/distutils/builtdist.html
        DESKTOP_FOLDER = get_special_folder_path("CSIDL_DESKTOPDIRECTORY")
    except:
        # but if we are not running it through the binary installer, we need to make calls to PyWin instead
        import win32com.client
        from win32com.shell import shell, shellcon
        
        DESKTOP_FOLDER = shell.SHGetFolderPath( 0,
                                                shellcon.CSIDL_DESKTOPDIRECTORY,
                                                None,0 )
        
        def create_shortcut( target, description, filename,
                             arguments, workdir, iconpath ):
            '''Make a shortcut with direct calls to Windows'''
            shell = win32com.client.Dispatch('WScript.Shell')
            shortcut = shell.CreateShortCut(filename)
            shortcut.TargetPath = target
            shortcut.Description = description
            shortcut.Arguments = arguments
            shortcut.WorkingDirectory = workdir
            shortcut.IconLocation = iconpath
            #shortcut.FullName
            # shortcut.Hotkey
            # shortcut.WindowStyle
            shortcut.Save()
        def file_created(filename):
            '''This is only used for uninstallation, and this will never run during installation'''
            pass
    
    if len(sys.argv)<2:
        print 'No option specified. Please append either "-install" or "-remove"'
    else:
        if sys.argv[1] == '-install':
            lnkName = name+'.lnk'
            pythonw = os.path.join( os.path.split(sys.executable)[0], 'pythonw.exe')
            create_shortcut(
                os.path.join(pythonw), # target
                name, # description
                lnkName, # filename
                os.path.join(modulePath, name+'.py'), # arguments
                '', # workdir
                os.path.join(modulePath,'icons',name+'.ico'), # iconpath
            )
            # move shortcut from current directory to DESKTOP_FOLDER
            shutil.move(os.path.join(os.getcwd(), lnkName),
                        os.path.join(DESKTOP_FOLDER, lnkName))
            # tell windows installer that we created another
            # file which should be deleted on uninstallation
            file_created(os.path.join(DESKTOP_FOLDER, lnkName))

        if sys.argv[1] == '-remove':
            pass
            # This will be run on uninstallation. Nothing to do.
